@@ -15,7 +15,7 @@ use Rose::HTML::Form::Field;
 use Rose::HTML::Form::Field::Collection;
 our @ISA = qw(Rose::HTML::Form::Field Rose::HTML::Form::Field::Collection);
 
-our $VERSION = '0.546';
+our $VERSION = '0.547';
 
 # Multiple inheritence never quite works out the way I want it to...
 Rose::HTML::Form::Field::Collection->import_methods
@@ -588,14 +588,14 @@ sub validate
 
   my $fail = 0;
 
-  if($args{'cascade'})
+  my $cascade = $args{'cascade'};
+
+  if($cascade)
   {
     foreach my $form ($self->forms)
     {
       $Debug && warn "Validating sub-form ", $form->form_name, "\n";
 
-      local $args{'form_only'} = 1;
-
       unless($form->validate(%args))
       {
         $self->add_error($form->error)  if($form->error);
@@ -608,8 +608,15 @@ sub validate
   {
     foreach my $field ($self->fields)
     {
-      $Debug && warn "Validating ", $field->name, "\n";
-      $fail++  unless($field->validate);
+      if($cascade && $field->parent_form ne $self)
+      {
+        $Debug && warn "Skipping redundant validation of ", $field->name, "\n";
+      }
+      else
+      {
+        $Debug && warn "Validating ", $field->name, "\n";
+        $fail++  unless($field->validate);
+      }
     }
   }
 
@@ -1197,6 +1204,8 @@ sub field
 
   my($parent_form, $local_name) = $self->find_parent_form($name);
 
+  return undef  unless($parent_form);
+
   return $self->{'field_cache'}{$name} = $parent_form->field($local_name, @_);
 }
 
