@@ -19,7 +19,7 @@ Rose::HTML::Form::Field::WithContents->import_methods(
   xhtml_tag => '_xhtml_tag',
 });
 
-our $VERSION = '0.545';
+our $VERSION = '0.547';
 
 sub _item_class       { 'Rose::HTML::Form::Field::Option' }
 sub _item_group_class { 'Rose::HTML::Form::Field::OptionGroup' }
@@ -89,7 +89,7 @@ sub hidden_fields
 
   foreach my $item ($self->items)
   {
-    if($item->internal_value)
+    if(defined $item->internal_value)
     {
       push(@hidden, $item->hidden_field);
       $hidden[-1]->name($self->name);
