@@ -6,7 +6,7 @@ use Carp;
 
 use base 'Rose::HTML::Object::Messages';
 
-our $VERSION = '0.54';
+our $VERSION = '0.544';
 
 BEGIN
 {
@@ -52,6 +52,9 @@ use constant NUM_NOT_POSITIVE_INTEGER     => 1302;
 use constant NUM_BELOW_MIN                => 1303;
 use constant NUM_ABOVE_MAX                => 1304;
 
+# String messages
+use constant STRING_OVERFLOW => 1400;
+
 # Date errors
 use constant DATE_INVALID              => 1500;
 use constant DATE_MIN_GREATER_THAN_MAX => 1501;
